@@ -155,6 +155,52 @@ def config_command(
         "--runtime_jwt_allowed_clients",
         help="Allowed OAuth2 client IDs when runtime_auth_type is custom_jwt (can be used multiple times)",
     ),
+    # Runtime bindings (resource associations)
+    memory_id: Optional[str] = typer.Option(
+        None,
+        "--memory_id",
+        "--runtime_binding_memory_id",
+        help="Bind Runtime to a Memory collection ID (cloud/hybrid only)",
+    ),
+    knowledge_id: Optional[str] = typer.Option(
+        None,
+        "--knowledge_id",
+        "--runtime_binding_knowledge_id",
+        help="Bind Runtime to a Knowledge ID (cloud/hybrid only)",
+    ),
+    tool_id: Optional[str] = typer.Option(
+        None,
+        "--tool_id",
+        "--runtime_binding_tool_id",
+        help="Bind Runtime to a Tool ID (cloud/hybrid only)",
+    ),
+    mcp_toolset_id: Optional[str] = typer.Option(
+        None,
+        "--mcp_toolset_id",
+        "--runtime_binding_mcp_toolset_id",
+        help="Bind Runtime to an MCP Toolset ID (cloud/hybrid only)",
+    ),
+    # Runtime network configuration (advanced, CreateRuntime only)
+    runtime_network_mode: Optional[str] = typer.Option(
+        None,
+        "--runtime_network_mode",
+        "--runtime-network-mode",
+        help="Runtime network mode (cloud/hybrid, CreateRuntime only): public/private/both",
+    ),
+    runtime_vpc_id: Optional[str] = typer.Option(
+        None,
+        "--runtime_vpc_id",
+        "--runtime-vpc-id",
+        help="Runtime VPC ID (cloud/hybrid, CreateRuntime only; required for private/both)",
+    ),
+    runtime_subnet_ids: Optional[List[str]] = typer.Option(
+        None,
+        "--runtime_subnet_ids",
+        "--runtime_subnet_id",
+        "--runtime-subnet-id",
+        "--runtime-subnet-ids",
+        help="Runtime subnet ID (repeatable; cloud/hybrid, CreateRuntime only)",
+    ),
 ):
     """Configure AgentKit (supports interactive and non-interactive modes).
     
@@ -254,6 +300,13 @@ def config_command(
             runtime_auth_type=runtime_auth_type,
             runtime_jwt_discovery_url=runtime_jwt_discovery_url,
             runtime_jwt_allowed_clients=runtime_jwt_allowed_clients,
+            memory_id=memory_id,
+            knowledge_id=knowledge_id,
+            tool_id=tool_id,
+            mcp_toolset_id=mcp_toolset_id,
+            runtime_network_mode=runtime_network_mode,
+            runtime_vpc_id=runtime_vpc_id,
+            runtime_subnet_ids=runtime_subnet_ids,
         )
 
         has_cli_params = ConfigParamHandler.has_cli_params(cli_params)
@@ -319,6 +372,25 @@ def _interactive_config(config_file: Optional[str] = None):
         console.print(f"[red]❌ Unknown launch type: {strategy_name}[/red]")
         raise typer.Exit(1)
 
+    # When disabling strict region restrictions, default show global region
+    try:
+        from agentkit.toolkit.config.global_config import get_global_config
+
+        global_conf = get_global_config()
+        disabled = bool(
+            getattr(global_conf.defaults, "disable_region_strict_restrictions", False)
+        )
+        if disabled and isinstance(current_strategy_config_dict, dict):
+            global_region = (global_conf.region or "").strip()
+            if global_region:
+                if "region" in current_strategy_config_dict:
+                    if not current_strategy_config_dict.get("region"):
+                        current_strategy_config_dict["region"] = global_region
+                else:
+                    current_strategy_config_dict["region"] = global_region
+    except Exception:
+        pass
+
     # Generate new strategy config
     strategy_config = generate_config_from_dataclass(
         config_class, current_strategy_config_dict
@@ -472,6 +544,8 @@ def _show_global_config():
     console.print(
         f"  Region:     [yellow]{config.region or '[dim](not set)[/dim]'}[/yellow]"
     )
+    if config.defaults.disable_region_strict_restrictions:
+        console.print("  Disable Region Restrictions: [yellow]True[/yellow]")
     console.print()
 
     # Display Volcengine credentials
@@ -581,22 +655,9 @@ def _set_global_field(field_value: str):
                 )
             config_dict[section][field] = clean_value
         elif field == "cr_public_endpoint_check":
-            clean_value = value.strip().lower() if value is not None else None
-            if clean_value == "":
-                clean_value = None
-            if clean_value is None:
-                config_dict[section][field] = None
-            else:
-                truthy = {"true", "1", "yes", "y"}
-                falsy = {"false", "0", "no", "n"}
-                if clean_value in truthy:
-                    config_dict[section][field] = True
-                elif clean_value in falsy:
-                    config_dict[section][field] = False
-                else:
-                    raise AttributeError(
-                        f"Invalid boolean value for cr_public_endpoint_check: {value}"
-                    )
+            _set_bool_field(config_dict[section], field, value)
+        elif field == "disable_region_strict_restrictions":
+            _set_bool_field(config_dict[section], field, value)
         elif field == "iam_role_policies":
             # Simple list parsing for CLI convenience
             if not value:
@@ -631,3 +692,22 @@ def _set_global_field(field_value: str):
     except Exception as e:
         console.print(f"[red]❌ Failed to set config: {e}[/red]")
         raise typer.Exit(code=1)
+
+
+def _set_bool_field(target_dict: dict, field: str, value: str):
+    """Helper to set boolean field from string value."""
+    clean_value = value.strip().lower() if value is not None else None
+    if clean_value == "":
+        clean_value = None
+
+    if clean_value is None:
+        target_dict[field] = None
+    else:
+        truthy = {"true", "1", "yes", "y"}
+        falsy = {"false", "0", "no", "n"}
+        if clean_value in truthy:
+            target_dict[field] = True
+        elif clean_value in falsy:
+            target_dict[field] = False
+        else:
+            raise AttributeError(f"Invalid boolean value for {field}: {value}")
