@@ -26,6 +26,11 @@ from pathlib import Path
 from typing import Optional
 import logging
 
+from agentkit.utils.global_config_io import (
+    read_global_config_dict,
+    write_global_config_dict,
+)
+
 from .utils import is_valid_config
 
 logger = logging.getLogger(__name__)
@@ -41,13 +46,11 @@ class VolcengineCredentials:
 
     access_key: str = ""
     secret_key: str = ""
-    region: str = "cn-beijing"
 
     def to_dict(self):
         return {
             "access_key": self.access_key,
             "secret_key": self.secret_key,
-            "region": self.region,
         }
 
     @classmethod
@@ -55,7 +58,6 @@ class VolcengineCredentials:
         return cls(
             access_key=data.get("access_key", ""),
             secret_key=data.get("secret_key", ""),
-            region=data.get("region", "cn-beijing"),
         )
 
 
@@ -71,16 +73,12 @@ class CRGlobalConfig:
     auto_create_instance_type: str = (
         "Micro"  # Instance type when auto-creating: "Micro" or "Enterprise"
     )
-    host: str = ""
-    schema: str = "https"
 
     def to_dict(self):
         return {
             "instance_name": self.instance_name,
             "namespace_name": self.namespace_name,
             "auto_create_instance_type": self.auto_create_instance_type,
-            "host": self.host,
-            "schema": self.schema,
         }
 
     @classmethod
@@ -89,8 +87,6 @@ class CRGlobalConfig:
             instance_name=data.get("instance_name", ""),
             namespace_name=data.get("namespace_name", ""),
             auto_create_instance_type=data.get("auto_create_instance_type", "Micro"),
-            host=data.get("host", ""),
-            schema=data.get("schema", "https"),
         )
 
 
@@ -98,18 +94,16 @@ class CRGlobalConfig:
 class TOSGlobalConfig:
     """TOS (object storage) global configuration.
 
-    Used when project config `tos_bucket`, `tos_prefix` or `tos_region` is empty or "Auto".
+    Used when project config `tos_bucket` or `tos_prefix` is empty or "Auto".
     """
 
     bucket: str = ""
     prefix: str = ""
-    region: str = ""
 
     def to_dict(self):
         return {
             "bucket": self.bucket,
             "prefix": self.prefix,
-            "region": self.region,
         }
 
     @classmethod
@@ -117,7 +111,6 @@ class TOSGlobalConfig:
         return cls(
             bucket=data.get("bucket", ""),
             prefix=data.get("prefix", ""),
-            region=data.get("region", ""),
         )
 
 
@@ -128,13 +121,12 @@ class GlobalConfig:
     Stored in ``~/.agentkit/config.yaml`` and shared across projects.
     """
 
+    region: str = ""
+
     volcengine: VolcengineCredentials = field(default_factory=VolcengineCredentials)
     cr: CRGlobalConfig = field(default_factory=CRGlobalConfig)
     tos: TOSGlobalConfig = field(default_factory=TOSGlobalConfig)
-    agentkit_host: str = ""
-    agentkit_schema: str = "https"
-    iam_host: str = ""
-    iam_schema: str = "https"
+    region_policy: dict = field(default_factory=dict)
 
     @dataclass
     class Defaults:
@@ -142,6 +134,7 @@ class GlobalConfig:
         preflight_mode: Optional[str] = None
         cr_public_endpoint_check: Optional[bool] = None
         iam_role_policies: Optional[list] = None
+        disable_region_strict_restrictions: Optional[bool] = None
 
         def to_dict(self):
             data = {}
@@ -153,6 +146,10 @@ class GlobalConfig:
                 data["cr_public_endpoint_check"] = self.cr_public_endpoint_check
             if self.iam_role_policies is not None:
                 data["iam_role_policies"] = self.iam_role_policies
+            if self.disable_region_strict_restrictions is not None:
+                data["disable_region_strict_restrictions"] = (
+                    self.disable_region_strict_restrictions
+                )
             return data
 
         @classmethod
@@ -162,6 +159,9 @@ class GlobalConfig:
                 preflight_mode=data.get("preflight_mode"),
                 cr_public_endpoint_check=data.get("cr_public_endpoint_check"),
                 iam_role_policies=data.get("iam_role_policies"),
+                disable_region_strict_restrictions=data.get(
+                    "disable_region_strict_restrictions"
+                ),
             )
 
     defaults: "GlobalConfig.Defaults" = field(
@@ -170,17 +170,11 @@ class GlobalConfig:
 
     def to_dict(self):
         base = {
+            "region": self.region,
             "volcengine": self.volcengine.to_dict(),
             "cr": self.cr.to_dict(),
             "tos": self.tos.to_dict(),
-            "agentkit": {
-                "host": self.agentkit_host,
-                "schema": self.agentkit_schema,
-            },
-            "iam": {
-                "host": self.iam_host,
-                "schema": self.iam_schema,
-            },
+            "region_policy": self.region_policy,
         }
         defaults_dict = self.defaults.to_dict()
         if defaults_dict:
@@ -189,14 +183,17 @@ class GlobalConfig:
 
     @classmethod
     def from_dict(cls, data: dict):
+        # Fallback: check nested volcengine.region if top-level region is missing
+        region = data.get("region", "")
+        if not region:
+            region = data.get("volcengine", {}).get("region", "")
+
         return cls(
+            region=region,
             volcengine=VolcengineCredentials.from_dict(data.get("volcengine", {})),
             cr=CRGlobalConfig.from_dict(data.get("cr", {})),
             tos=TOSGlobalConfig.from_dict(data.get("tos", {})),
-            agentkit_host=(data.get("agentkit", {}) or {}).get("host", ""),
-            agentkit_schema=(data.get("agentkit", {}) or {}).get("schema", "https"),
-            iam_host=(data.get("iam", {}) or {}).get("host", ""),
-            iam_schema=(data.get("iam", {}) or {}).get("schema", "https"),
+            region_policy=data.get("region_policy", {}),
             defaults=GlobalConfig.Defaults.from_dict(data.get("defaults", {}) or {}),
         )
 
@@ -228,20 +225,18 @@ class GlobalConfigManager:
         Returns:
             GlobalConfig instance
         """
-        if not self.config_path.exists():
-            logger.debug(f"Global config file does not exist: {self.config_path}")
+        data = read_global_config_dict(self.config_path)
+        if not data:
+            logger.debug(
+                f"Global config file does not exist or empty: {self.config_path}"
+            )
             return GlobalConfig()
-
         try:
-            import yaml
-
-            with open(self.config_path, "r", encoding="utf-8") as f:
-                data = yaml.safe_load(f) or {}
             logger.debug(f"Loaded global config from: {self.config_path}")
             return GlobalConfig.from_dict(data)
         except Exception as e:
             logger.debug(
-                f"Failed to load global config, using empty config: {e}", exc_info=True
+                f"Failed to parse global config, using empty config: {e}", exc_info=True
             )
             return GlobalConfig()
 
@@ -251,27 +246,7 @@ class GlobalConfigManager:
         Args:
             config: Configuration object to persist
         """
-        # Ensure parent directory exists
-        self.config_path.parent.mkdir(parents=True, exist_ok=True)
-
-        # Write YAML config
-        with open(self.config_path, "w", encoding="utf-8") as f:
-            import yaml
-
-            yaml.dump(
-                config.to_dict(),
-                f,
-                default_flow_style=False,
-                allow_unicode=True,
-                sort_keys=False,
-            )
-
-        # Restrict file permission to owner read/write only
-        try:
-            self.config_path.chmod(0o600)
-        except Exception as e:
-            logger.warning(f"Failed to set config file permission: {e}")
-
+        write_global_config_dict(config.to_dict(), self.config_path)
         logger.info(f"Global config saved: {self.config_path}")
 
     def get_config(self, force_reload: bool = False) -> GlobalConfig:
@@ -408,21 +383,6 @@ def apply_global_config_defaults(
                 {
                     "tos_bucket": ("tos", "bucket"),
                     "tos_prefix": ("tos", "prefix"),
-                    "tos_region": ("tos", "region"),
-                }
-            )
-
-        # Region fields (cloud/hybrid) inherit from global volcengine.region when project missing
-        if isinstance(config_obj, (HybridStrategyConfig, CloudStrategyConfig)):
-            field_mappings.update(
-                {
-                    "region": ("volcengine", "region"),
-                }
-            )
-        if isinstance(config_obj, CloudStrategyConfig):
-            field_mappings.update(
-                {
-                    "cr_region": ("volcengine", "region"),
                 }
             )
 
